
quoter
======

``quoter`` provides a simple, powerful, systematic way do accomplish
one of the most common low-level operations in Python programming:
combing strings and data objects into other strings. It does so with
remarkable intelligence, including for complex textual langauges
such as HTML and XML.

.. toctree::
   :titlesonly:

   intro
   core
   install
   CHANGES
